import * as React from "react";
import { RecordOf } from "immutable";
import { WidgetManager } from "./widget-manager";
import { KernelNotStartedProps, LocalKernelProps, RemoteKernelProps, ContentRef } from "@nteract/core";
import { CellId } from "@nteract/commutable";
import { WidgetModel } from "@jupyter-widgets/base";
interface ConnectedProps {
    modelById: (id: string) => any;
    kernel?: RecordOf<KernelNotStartedProps> | RecordOf<LocalKernelProps> | RecordOf<RemoteKernelProps> | null;
}
export interface ManagerActions {
    actions: {
        appendOutput: (output: any) => void;
        clearOutput: () => void;
        updateCellStatus: (status: string) => void;
        promptInputRequest: (prompt: string, password: boolean) => void;
    };
}
interface OwnProps {
    model: WidgetModel;
    model_id: string;
    id: CellId;
    contentRef: ContentRef;
}
declare type Props = ConnectedProps & OwnProps & ManagerActions;
/**
 * This component is is a wrapper component that initializes a
 * WidgetManager singleton and passes a model reference to the
 * BackboneModelWrapper. It's doing most of the heavy lifting with
 * respect to bridging the kernels comms that the WidgetManager provides,
 * our client-side state model, and the view.
 */
declare class Manager extends React.Component<Props> {
    widgetContainerRef: React.RefObject<HTMLDivElement>;
    static manager: WidgetManager;
    constructor(props: Props);
    /**
     * Because the iPyWidgets keeps track of the widgets it creates as a
     * member variable, the WidgetManager needs to be treated like a singleton.
     * However, we still need to be constantly updating the singleton with the most up
     * to date modelById function, otherwise it will be searching a stale state for a
     * model
     */
    getManager(): WidgetManager;
    render(): JSX.Element;
}
declare const _default: import("react-redux").ConnectedComponentClass<typeof Manager, Pick<Props, "id" | "model" | "model_id" | "contentRef"> & OwnProps>;
export default _default;
