import { KernelMessage } from "@jupyterlab/services";
import * as base from "@jupyter-widgets/base";
import { DOMWidgetView, WidgetModel } from "@jupyter-widgets/base";
import { WidgetComm } from "./widget-comms";
import { RecordOf } from "immutable";
import { KernelNotStartedProps, LocalKernelProps, RemoteKernelProps } from "@nteract/core";
import { ManagerActions } from "../manager/index";
/**
 * The WidgetManager extends the ManagerBase class and is required
 * by the ipywidgets implementation for rendering all models. This
 * WidgetManager contains some overrides to get it to play nice
 * with our RxJS-based kernel communication.
 */
export declare class WidgetManager extends base.ManagerBase<DOMWidgetView> {
    stateModelById: (id: string) => any;
    kernel: RecordOf<KernelNotStartedProps> | RecordOf<LocalKernelProps> | RecordOf<RemoteKernelProps> | null;
    actions: ManagerActions["actions"];
    widgetsBeingCreated: {
        [model_id: string]: Promise<WidgetModel>;
    };
    constructor(kernel: any, stateModelById: (id: string) => any, actions: ManagerActions["actions"]);
    update(kernel: any, stateModelById: (id: string) => any, actions: ManagerActions["actions"]): void;
    /**
     * Load a class and return a promise to the loaded object.
     */
    loadClass(className: string, moduleName: string, moduleVersion: string): any;
    /**
     * Get a promise for a model by model id.
     *
     * #### Notes
     * If a model is not found, this will lookup the model in nteracts
     * redux store using the model_comm_lookup funciton and create it
     */
    get_model(model_id: string): Promise<WidgetModel> | undefined;
    /**
     * Shortcut to new_widget (creates the modelInfo from the state)
     * @param state
     * @param model_id
     */
    new_widget_from_state_and_id(state: any, model_id: string): Promise<base.WidgetModel>;
    /**
     * Create a comm and new widget model.
     * @param  options - same options as new_model but comm is not
     *                          required and additional options are available.
     * @param  serialized_state - serialized model attributes.
     */
    new_widget(options: any, serialized_state?: any): Promise<WidgetModel>;
    /**
     * Do not use this method. Use `render_view` instead for displaying the widget.
     *
     * This method is here because it is required to be implemented by the ManagerBase,
     * so even though it is not used, do not delete it.
     * @param msg
     * @param view
     * @param options
     */
    display_view(msg: KernelMessage.IMessage, view: base.DOMWidgetView, options: any): Promise<base.DOMWidgetView>;
    /**
     * The ManagerBase type definition for the callbacks method expects
     * the message types to be as defined by the IMessage interface from
     * @jupyterlab/services. It is typed as any here so that we can use
     * our JupyterMessage types that are emitted from our kernel.channels
     * pipeline.
     */
    callbacks(): any;
    /**
     * Render the given view to a target element
     * @param view View to be rendered
     * @param el Target element that the view will be rendered within
     */
    render_view(view: base.DOMWidgetView, el: HTMLElement): void;
    _get_comm_info(): Promise<{}>;
    /**
     * Create a comm which can be used for communication for a widget.
     *
     * If the data/metadata is passed in, open the comm before returning (i.e.,
     * send the comm_open message). If the data and metadata is undefined, we
     * want to reconstruct a comm that already exists in the kernel, so do not
     * open the comm by sending the comm_open message.
     *
     * @param comm_target_name Comm target name
     * @param model_id The comm id
     * @param data The initial data for the comm
     * @param metadata The metadata in the open message
     */
    _create_comm(comm_target_name: string, model_id: string, data?: any, metadata?: any, buffers?: ArrayBuffer[] | ArrayBufferView[]): Promise<WidgetComm>;
}
